diff --git a/doc/src/sgml/fdwhandler.sgml b/doc/src/sgml/fdwhandler.sgml
index 46b8db8..d6fa98c 100644
--- a/doc/src/sgml/fdwhandler.sgml
+++ b/doc/src/sgml/fdwhandler.sgml
@@ -1014,6 +1014,10 @@ GetForeignServerByName(const char *name, bool missing_ok);
      source provides.
     </para>
 
+    <!-- FIXME: If this is a hard limitation with the backend, the backend
+         should check and reject these cases. Otherwise, if it's possible
+         that a FDW would actually support this, this needs to be reworded
+      -->
     <para>
      <command>INSERT</> with an <literal>ON CONFLICT</> clause is not
      supported with a unique index inference specification.  When
diff --git a/doc/src/sgml/ref/create_view.sgml b/doc/src/sgml/ref/create_view.sgml
index 2b68121..24fb4b7 100644
--- a/doc/src/sgml/ref/create_view.sgml
+++ b/doc/src/sgml/ref/create_view.sgml
@@ -385,6 +385,7 @@ CREATE VIEW vista AS SELECT text 'Hello World' AS hello;
     <xref linkend="rules-privileges">).
    </para>
    <para>
+    <!-- FIXME: This paragraph needs to reworded, to make it more readable. -->
     <command>INSERT</command> with an <literal>ON CONFLICT IGNORE</>
     clause is only supported on updatable views under specific
     circumstances.  If a set of columns/expressions has been provided
diff --git a/doc/src/sgml/ref/insert.sgml b/doc/src/sgml/ref/insert.sgml
index 1395c48..4f3878b 100644
--- a/doc/src/sgml/ref/insert.sgml
+++ b/doc/src/sgml/ref/insert.sgml
@@ -33,9 +33,12 @@ INSERT INTO <replaceable class="PARAMETER">table_name</replaceable> [ ( <replace
   <title>Description</title>
 
   <para>
-   <command>INSERT</command> inserts new rows into a table.  One can
-   insert one or more rows specified by value expressions, or zero or
-   more rows resulting from a query.  An alternative
+   <command>INSERT</command> inserts new rows into a table.
+   One can insert one or more rows specified by value expressions,
+   or zero or more rows resulting from a query.
+   <!-- FIXME: This needs to go somewhere later, not in the very first
+        introductory paragraph on INSERT in general -->
+   An alternative
    <literal>IGNORE</literal> path can optionally be specified, to be
    taken in the event of detecting that proceeding with insertion
    would result in a conflict (i.e. a conflicting tuple already
diff --git a/doc/src/sgml/ref/set_constraints.sgml b/doc/src/sgml/ref/set_constraints.sgml
index 5030f3c..b1e8f9b 100644
--- a/doc/src/sgml/ref/set_constraints.sgml
+++ b/doc/src/sgml/ref/set_constraints.sgml
@@ -69,7 +69,11 @@ SET CONSTRAINTS { ALL | <replaceable class="parameter">name</replaceable> [, ...
   <para>
    Currently, only <literal>UNIQUE</>, <literal>PRIMARY KEY</>,
    <literal>REFERENCES</> (foreign key), and <literal>EXCLUDE</>
-   constraints are affected by this setting.  Note that constraints
+   constraints are affected by this setting.
+   <!-- FIXME: I take that this is meant to say that DEFERRED constraints
+        cannot be used as arbiters. e.g.  SET CONSTRAINTS ALL IMMEDIATE is
+        OK. -->
+   Note that constraints
    that were created with this clause cannot be used as arbiters of
    whether or not to take the alternative path with an
    <command>INSERT</command> statement that includes an <literal>ON
diff --git a/src/backend/executor/execUtils.c b/src/backend/executor/execUtils.c
index ffe1d62..0dabd16 100644
--- a/src/backend/executor/execUtils.c
+++ b/src/backend/executor/execUtils.c
@@ -1548,6 +1548,7 @@ retry:
 			if (DirtySnapshot.speculativeToken)
 				SpeculativeInsertionWait(DirtySnapshot.xmin,
 										 DirtySnapshot.speculativeToken);
+			/* FIXME: both arms of this if do the same thing. Huh? */
 			else if (violationOK)
 				XactLockTableWait(xwait, heap, &ctid_wait,
 								  XLTW_RecheckExclusionConstr);
diff --git a/src/backend/optimizer/path/indxpath.c b/src/backend/optimizer/path/indxpath.c
index 99c8d6a..d31db33 100644
--- a/src/backend/optimizer/path/indxpath.c
+++ b/src/backend/optimizer/path/indxpath.c
@@ -4118,10 +4118,10 @@ string_to_const(const char *str, Oid datatype)
  * plan_speculative_use_index
  *		Use the planner to decide speculative insertion arbiter index
  *
- * Among indexes on target of INSERT ... ON CONFLICT,  decide which index to
+ * Among indexes on target of INSERT ... ON CONFLICT, decide which index to
  * use to arbitrate taking alternative path.  This should be called
- * infrequently in practice, because its unusual for more than one index to be
- * available that can satisfy a user-specified unique index inference
+ * infrequently in practice, because it's unusual for more than one index to
+ * be available that can satisfy a user-specified unique index inference
  * specification.
  *
  * Note: caller had better already hold some type of lock on the table.
